@@ -14,11 +14,13 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 import os
 import re
 import sys
 import OpenSSL
-from calculate.console.application.function import _print
+from .function import _print
 
 from calculate.core.datavars import DataVarsCore
 from calculate.lib.utils.files import readFile
@@ -57,12 +59,12 @@ def verify(server_cert, crl_path, flag):
             host = L.split(':')[0]
         except:
             if not flag:
-                print _("fields CN and L in the CA certificate are incorrect!")
+                print(_("fields CN and L in the CA certificate are incorrect!"))
             return 0
         crl_file = crl_path + host
     else:
         if not flag:
-            print _("fields CN and L in the CA certificate are incorrect!")
+            print(_("fields CN and L in the CA certificate are incorrect!"))
         return 0
 
     if not os.path.exists(crl_file):
@@ -82,16 +84,16 @@ def verify(server_cert, crl_path, flag):
 
     for rvk in revoked_objects:
         if serverSerial == int(rvk.get_serial(), 16):
-            print _("This certificate has been revoked!")
-            print _("Serial") + _(': %s\n') % rvk.get_serial() + _(
-                "Revoke date") + _(': %s') % rvk.get_rev_date()
+            print(_("This certificate has been revoked!"))
+            print(_("Serial") + _(': %s\n') % rvk.get_serial() + _(
+                "Revoke date") + _(': %s') % rvk.get_rev_date())
 
             raise VerifyError('CRL Exception')
     return 0
 
 
 def get_CRL(path_to_cert):
-    print 'update CRL'
+    print('update CRL')
     """ get new CRL (Certificate Revocation List) from all CA """
     # local CRL
     CRL_path = os.path.join(path_to_cert, 'ca/crl/')
@@ -101,13 +103,13 @@ def get_CRL(path_to_cert):
                 try:
                     os.makedirs(path_to_cert)
                 except OSError:
-                    print _("Failed to create directory %s") % path_to_cert
+                    print(_("Failed to create directory %s") % path_to_cert)
                     raise Exception(1)
             try:
                 os.makedirs(os.path.join(path_to_cert, 'ca'))
             except OSError:
-                print _("Failed to create directory %s") % (
-                    os.path.join(path_to_cert, 'ca'))
+                print(_("Failed to create directory %s") % (
+                    os.path.join(path_to_cert, 'ca')))
                 raise Exception(1)
         os.makedirs(CRL_path)
 
@@ -153,8 +155,8 @@ def get_CRL(path_to_cert):
 
         if url:
             new_crl = None
-            from client_class import Client_suds
-            from client_class import HTTPSClientCertTransport
+            from .client_class import Client_suds
+            from .client_class import HTTPSClientCertTransport
             # connect to ca server (url get from certificates)
             client = None
             try:
@@ -164,7 +166,7 @@ def get_CRL(path_to_cert):
 
                 client.set_parameters(path_to_cert, None, None, None)
                 new_crl = client.service.get_crl()
-            except VerifyError, e:
+            except VerifyError as e:
                 _print(e.value)
                 # rm_ca_from_trusted(ca)
                 raise Exception(1)
@@ -188,7 +190,7 @@ def get_CRL(path_to_cert):
 
                 with open(CRL_file, 'w') as fd:
                     fd.write(new_crl)
-                print _("CRL added")
+                print(_("CRL added"))
     find_ca_in_crl(CRL_path, all_ca_certs_list)
 
 
@@ -243,7 +245,7 @@ def rm_ca_from_trusted(ca_cert):
     import hashlib
 
     md5 = hashlib.md5()
-    md5.update(ca_cert)
+    md5.update(ca_cert.encode("UTF-8"))
     md5sum = md5.hexdigest()
 
     # search ca certificate in user ca list
@@ -260,8 +262,8 @@ def rm_ca_from_trusted(ca_cert):
                 if ca_cert == readFile(filename):
                     try:
                         os.unlink(filename)
-                    except OSError, e:
-                        _print(e.message)
+                    except OSError as e:
+                        _print(e)
                 else:
                     newfile += (line + '\n')
             else:
@@ -284,8 +286,8 @@ def rm_ca_from_trusted(ca_cert):
             if ca_cert != cert:
                 new_user_ca_certs.append(cert)
             else:
-                print _("CA certificate deleted from the list of user "
-                        "trusted certificates")
+                print(_("CA certificate deleted from the list of user "
+                        "trusted certificates"))
 
         fd = open(user_ca_db, 'w')
         for cert in new_user_ca_certs:
@@ -304,8 +306,8 @@ def rm_ca_from_trusted(ca_cert):
             if ca_cert != cert:
                 new_system_ca_certs.append(cert)
             else:
-                print _("CA certificate deleted from the list of system "
-                        "trusted certificates")
+                print(_("CA certificate deleted from the list of system "
+                        "trusted certificates"))
 
         fd = open(system_ca_db, 'w')
         for cert in new_system_ca_certs:
