@@ -13,33 +13,36 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+from __future__ import print_function
+from __future__ import absolute_import
 from calculate.core.server.local_call import Display, Methods, has_force_arg
 from calculate.lib.utils.tools import unpack_single_opts
 
 import calculate.contrib
 from suds import WebFault
 from suds.transport import TransportError
-from client_class import Client_suds
+from .client_class import Client_suds
 import traceback as tb
 import time
 import logging
 import os
 import sys
 import threading
-import urllib2
-from pid_information import client_list_methods
-from cert_func import (client_post_auth, client_post_request, client_get_cert,
+import urllib.request as urllib2
+from urllib.error import URLError
+from .pid_information import client_list_methods
+from .cert_func import (client_post_auth, client_post_request, client_get_cert,
                        client_post_cert, get_password_from_daemon,
                        clear_password)
-from sid_func import session_clean, client_session_info, client_session_list
-from cert_verify import get_CRL, VerifyError
+from .sid_func import session_clean, client_session_info, client_session_list
+from .cert_verify import get_CRL, VerifyError
 
 import M2Crypto
 import OpenSSL
 from calculate.core.datavars import DataVarsCore
-from client_class import HTTPSClientCertTransport
-from methods_func import call_method, get_method_argparser, parse, get_view
-from function import (MessageReceiver, MessageDispatcher, clear, _print,
+from .client_class import HTTPSClientCertTransport
+from .methods_func import call_method, get_method_argparser, parse, get_view
+from .function import (MessageReceiver, MessageDispatcher, clear, _print,
                       get_view_params)
 from calculate.lib.utils.files import makeDirectory, readLinesFile
 from calculate.lib.cl_lang import setLocalTranslate
@@ -70,15 +73,15 @@ def client_signal(client):
         try:
             client.service.active_client(sid)
         except:
-            print _('no connection to the server!')
+            print(_('no connection to the server!'))
             raise Exception(1)
         time.sleep(float(client_active))
 
 
 class StoppableThread(threading.Thread):
     def __init__(self):
-        super(StoppableThread, self).__init__()
-        self._stop = threading.Event()
+        super().__init__()
+        self._thread_stopped = threading.Event()
         self._pause = threading.Event()
         self._paused = threading.Event()
 
@@ -107,10 +110,10 @@ class StoppableThread(threading.Thread):
         self._pause.clear()
 
     def stop(self):
-        self._stop.set()
+        self._thread_stopped.set()
 
     def stopped(self):
-        return self._stop.isSet()
+        return self._thread_stopped.isSet()
 
     def paused(self):
         return self._pause.isSet()
@@ -141,7 +144,7 @@ def connect_with_cert(cert, path_to_cert, url, args, wait_thread, clVarsCore,
             url, transport=HTTPSClientCertTransport(
                 CERT_KEY, CERT_FILE, path_to_cert, password=key_passwd,
                 ca_certs=ca_certs, wait_thread=wait_thread))
-        if not wait_thread.isAlive():
+        if not wait_thread.is_alive():
             wait_thread = StoppableThread()
             flag_thread_start = True
             wait_thread.start()
@@ -150,19 +153,19 @@ def connect_with_cert(cert, path_to_cert, url, args, wait_thread, clVarsCore,
         wait_thread.stop()
         client_post_cert(client, clVarsCore)
         Connect_Error = 0
-    except VerifyError, e:
+    except VerifyError as e:
         Connect_Error = 1
         er = e
-    except OpenSSL.crypto.Error, e:
+    except OpenSSL.crypto.Error as e:
         Connect_Error = 1
         crypto_Error = 1
         er = e
-    except urllib2.URLError, e:
+    except URLError as e:
         Connect_Error = 1
         er = e
     except Exception as e:
         er = e
-        if e.message == 3:
+        if e == 3:
             wait_thread.stop()
             sys.exit(1)
         Connect_Error = 1
@@ -205,8 +208,8 @@ def add_server_hostname(host, path_to_cert, server_hostname):
         fd.write(temp_file)
         fd.close()
         return True
-    except Exception, e:
-        print e
+    except Exception as e:
+        print(e)
         return False
 
 
@@ -233,7 +236,7 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
         return 0
 
     if args.pid_res == "list":
-        from pid_information import client_pid_info
+        from .pid_information import client_pid_info
         wait_thread.stop()
         client_pid_info(client, wait_thread)
         return 0
@@ -246,7 +249,7 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
     if args.pid_res:
         wait_thread.stop()
         if not args.pid_res.isdigit():
-            print _("Wrong PID")
+            print(_("Wrong PID"))
             return 1
         mr = get_entire_message_receiver(client, int(args.pid_res))
         if mr:
@@ -259,7 +262,7 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
 
     if args.pid_kill:
         wait_thread.stop()
-        from pid_information import client_pid_kill
+        from .pid_information import client_pid_kill
 
         return client_pid_kill(client, args.pid_kill)
 
@@ -306,25 +309,25 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
             try:
                 mr.analysis(method_result)
                 # analysis(client, client.sid, method_result)
-            except urllib2.URLError, e:
+            except URLError as e:
                 _print(e)
             except KeyboardInterrupt:
                 try:
-                    print
+                    print()
                     mess = method_result[0][0]
                     pid = int(mess.message)
                     result = client.service.pid_kill(pid, client.sid)
                     if result in [0, 2]:
-                        print _('Process terminated')
+                        print(_('Process terminated'))
                     elif result == -1:
-                        print _("Certificate not found on the server")
+                        print(_("Certificate not found on the server"))
                     elif result == -2:
-                        print _("Session not matching your certificate")
+                        print(_("Session not matching your certificate"))
                     elif result == 1:
-                        print _("Failed to terminate the process")
+                        print(_("Failed to terminate the process"))
                     mr.analysis(method_result)
-                except Exception, e:
-                    _print(e.message)
+                except Exception as e:
+                    _print(e)
 
             try:
                 mess = method_result[0][0]
@@ -397,6 +400,7 @@ def main(wait_thread):
     port = args.port or clVarsCore.GetInteger('core.cl_core_port')
     host = args.host
     path_to_cert = args.path_to_cert
+    
     if not path_to_cert:
         path_to_cert = clVarsCore.Get('core.cl_client_cert_dir')
     path_to_cert = path_to_cert.replace("~", homePath)
@@ -408,7 +412,7 @@ def main(wait_thread):
                 wait_thread.stop()
                 sys.stdout.write('\r')
                 sys.stdout.flush()
-                print _("Failed to create directory %s") % dir_path
+                print(_("Failed to create directory %s") % dir_path)
                 return 1
 
     if args.update_crl:
@@ -416,7 +420,7 @@ def main(wait_thread):
         getCRL = threading.Thread(target=get_CRL, args=(path_to_cert,))
         getCRL.start()
         getCRL.join()
-        print 'CRL updated'
+        print('CRL updated')
         return 0
 
     if args.by_host:
@@ -429,7 +433,7 @@ def main(wait_thread):
         return 0
 
     url = "https://%s:%s/?wsdl" % (host, port)
-
+    
     try:
         from calculate.lib.utils.dbus_tools import run_dbus_core
         run_dbus_core(host, port)
@@ -440,6 +444,7 @@ def main(wait_thread):
     serv_hostname = get_server_hostname(host, path_to_cert)
     get_name_flag = False
     client = None
+    
     if serv_hostname:
         Connect_Error = 1
         crypto_Error = 0
@@ -447,7 +452,7 @@ def main(wait_thread):
             connect_with_cert(serv_hostname, path_to_cert, url, args,
                               wait_thread, clVarsCore, crypto_Error,
                               Connect_Error)
-        if not wait_thread.isAlive():
+        if not wait_thread.is_alive():
             wait_thread = StoppableThread()
             wait_thread.start()
         get_name_flag = True
@@ -456,13 +461,13 @@ def main(wait_thread):
                 wait_thread.stop()
                 sys.stdout.write('\r')
                 sys.stdout.flush()
-                print _('Invalid password')
+                print(_('Invalid password'))
                 # delete password from daemon list
                 clear_password(host, port)
             elif e:
                 wait_thread.stop()
-                if type(e.message) != int:
-                    print _('Error: '), e
+                if type(e) != int:
+                    print(_('Error: '), e)
             get_name_flag = False
 
     if get_name_flag:
@@ -473,33 +478,33 @@ def main(wait_thread):
                 try:
                     return_val = https_server(client, args, unknown_args, url,
                                               clVarsCore, wait_thread)
-                except urllib2.URLError, e:
-                    print _('Error: '), e
+                except URLError as e:
+                    print(_('Error: '), e)
                 except KeyboardInterrupt:
                     wait_thread.stop()
                     red = '\n' + '\033[31m * \033[0m'
-                    print red + _("Manually interrupted")
-                except Exception, e:
+                    print(red + _("Manually interrupted"))
+                except Exception as e:
                     wait_thread.stop()
-                    if type(e.message) != int:
-                        if e.message:
-                            print e.message
+                    if type(e) != int:
+                        if e:
+                            print(e)
                         elif e.args:
-                            print e
+                            print(e)
                     return 1
                 wait_thread.stop()
                 return return_val
-            except WebFault, f:
-                print _("Exception: %s") % f
+            except WebFault as f:
+                print(_("Exception: %s") % f)
                 _print(f.fault)
-            except TransportError, te:
-                print _("Exception: %s") % te
+            except TransportError as te:
+                print(_("Exception: %s") % te)
             except KeyboardInterrupt:
                 wait_thread.stop()
                 red = '\n' + '\033[31m * \033[0m'
-                print red + _("Manually interrupted")
-            except Exception, e:
-                print _("Exception: %s") % e
+                print(red + _("Manually interrupted"))
+            except Exception as e:
+                print(_("Exception: %s") % e)
                 tb.print_exc()
         wait_thread.stop()
 
@@ -510,16 +515,16 @@ def main(wait_thread):
         client.wsdl.services[0].setlocation(url)
         server_host_name = client.service.get_server_host_name()
         if not add_server_hostname(host, path_to_cert, server_host_name):
-            print 'compliance_file write error!'
+            print('compliance_file write error!')
         del client
-    except urllib2.URLError, e:
+    except URLError as e:
         wait_thread.stop()
-        print '\b' + _('Failed to connect') + ':', e
+        print('\b' + _('Failed to connect') + ':', e)
         return 1
     except KeyboardInterrupt:
         wait_thread.stop()
         red = '\n' + '\033[31m * \033[0m'
-        print red + _("Manually interrupted")
+        print(red + _("Manually interrupted"))
 
     try:
         import glob
@@ -543,7 +548,7 @@ def main(wait_thread):
                 connect_with_cert(cert_name, path_to_cert, url, args,
                                   wait_thread, clVarsCore, crypto_Error,
                                   Connect_Error)
-            if not wait_thread.isAlive():
+            if not wait_thread.is_alive():
                 wait_thread = StoppableThread()
                 wait_thread.start()
 
@@ -556,14 +561,14 @@ def main(wait_thread):
                 wait_thread.stop()
                 sys.stdout.write('\r')
                 sys.stdout.flush()
-                print _('Invalid password')
+                print(_('Invalid password'))
                 # delete password from daemon list
                 clear_password(host, port)
                 return 1
             elif e:
                 wait_thread.stop()
-                if type(e.message) != int:
-                    print _('Error: '), e
+                if type(e) != int:
+                    print(_('Error: '), e)
                 return 1
 
             CERT_FILE = None
@@ -579,34 +584,34 @@ def main(wait_thread):
         try:
             return_val = https_server(client, args, unknown_args, url,
                                       clVarsCore, wait_thread)
-        except urllib2.URLError, e:
-            print _('Error: '), e
+        except URLError as e:
+            print(_('Error: '), e)
         except KeyboardInterrupt:
             wait_thread.stop()
             red = '\n' + '\033[31m * \033[0m'
-            print red + _("Manually interrupted")
-        except Exception, e:
+            print(red + _("Manually interrupted"))
+        except Exception as e:
             wait_thread.stop()
-            if type(e.message) != int:
-                if e.message:
-                    print e.message
+            if type(e) != int:
+                if e:
+                    print(e)
                 elif e.args:
-                    print e
+                    print(e)
                     #                tb.print_exc()
             return 1
         wait_thread.stop()
         return return_val
     # ----------------------------------------------------
-    except WebFault, f:
-        print _("Exception: %s") % f
+    except WebFault as f:
+        print(_("Exception: %s") % f)
         _print(f.fault)
-    except TransportError, te:
-        print _("Exception: %s") % te
+    except TransportError as te:
+        print(_("Exception: %s") % te)
     except KeyboardInterrupt:
         wait_thread.stop()
         red = '\n' + '\033[31m * \033[0m'
-        print red + _("Manually interrupted")
-    except Exception, e:
-        print _("Exception: %s") % e
+        print(red + _("Manually interrupted"))
+    except Exception as e:
+        print(_("Exception: %s") % e)
         tb.print_exc()
     wait_thread.stop()
