@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
 import time
 import os
 import sys
@@ -34,7 +35,7 @@ setLocalTranslate('cl_console3', sys.modules[__name__])
 
 
 def _print(*args):
-    print " ".join(map(lambda x: unicode(x).encode('utf-8'), args))
+    print(" ".join(map(str, args)))
 
 
 # get list of certificate and session id
@@ -49,14 +50,14 @@ def clear():
             try:
                 os.unlink(filename)
             except OSError as e:
-                _print(e.message)
+                _print(e)
     except Exception:
-        print _("Failed to clear the cache! ")
+        print(_("Failed to clear the cache! "))
         return 1
 
 
 def get_ip_global():
-    import urllib2
+    import urllib.request as urllib2
 
     strURL = 'http://api.wipmania.com/'
     f = urllib2.urlopen(urllib2.Request(strURL))
