@@ -14,16 +14,19 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+# from __future__ import print_function
+# from __future__ import absolute_import
 import argparse
 import sys
 from calculate.core.server.api_types import ViewInfoAdapter
 from calculate.core.server.local_call import Methods, has_force_arg
-from function import _create_obj, get_view_params, print_brief, _print
+from .function import _create_obj, get_view_params, print_brief, _print
 from calculate.lib.cl_lang import setLocalTranslate
+from urllib.error import URLError
 
 _ = lambda x: x
 setLocalTranslate('cl_console3', sys.modules[__name__])
-import urllib2
+import urllib.request as urllib2
 
 from calculate.core.server.methods_func import get_method_argparser, \
     collect_object, RawAndDefaultsHelpFormatter, \
@@ -99,7 +102,7 @@ def parse():
 def get_view(client, method, sid, view_params):
     try:
         view = client.service[0][method + '_view'](client.sid, view_params)
-    except urllib2.URLError, e:
+    except URLError as e:
         _print(_('Failed to connect') + ':', e)
         raise Exception(1)
     return view
@@ -167,7 +170,7 @@ def call_method(client, args, unknown_args, wait_thread):
                 method_result = client.service[0][method](client.sid,
                                                           param_object)
                 if not method_result:
-                    print _('Method not available')
+                    print(_('Method not available'))
                     return None
                 if (method_result.ReturnedMessage[0].type and
                             method_result.ReturnedMessage[0].type != "pid"):
@@ -204,7 +207,7 @@ def call_method(client, args, unknown_args, wait_thread):
         param_object = {}
     method_result = client.service[0][method](client.sid, param_object)
     if not method_result:
-        print _('Method not available')
+        print(_('Method not available'))
         return None
     if (method_result.ReturnedMessage[0].type and
                 method_result.ReturnedMessage[0].type != "pid"):
